"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clear = exports.set = exports.get = exports.getAll = void 0;
var tslib_1 = require("tslib");
var cookie_1 = require("cookie");
var getAll = function (req) {
    return cookie_1.parse(req.headers.cookie || '');
};
exports.getAll = getAll;
var get = function (req, name) {
    var cookies = exports.getAll(req);
    return cookies[name];
};
exports.get = get;
var set = function (res, name, value, options) {
    if (options === void 0) { options = {}; }
    var strCookie = cookie_1.serialize(name, value, options);
    var previousCookies = res.getHeader('Set-Cookie') || [];
    if (!Array.isArray(previousCookies)) {
        previousCookies = [previousCookies];
    }
    res.setHeader('Set-Cookie', tslib_1.__spread(previousCookies, [strCookie]));
};
exports.set = set;
var clear = function (res, name, options) {
    if (options === void 0) { options = {}; }
    var domain = options.domain, path = options.path, secure = options.secure, sameSite = options.sameSite;
    var clearOptions = {
        domain: domain,
        path: path,
        maxAge: 0
    };
    // If SameSite=None is set, the cookie Secure attribute must also be set (or the cookie will be blocked)
    // https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie/SameSite#none
    if (sameSite === 'none') {
        clearOptions.secure = secure;
        clearOptions.sameSite = sameSite;
    }
    exports.set(res, name, '', clearOptions);
};
exports.clear = clear;
//# sourceMappingURL=cookies.js.map